<?php
/**
 * Narcissism functions and definitions
 *
 * @package Narcissism
 */

if ( ! function_exists( 'narcissism_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function narcissism_setup() {
    
    /**
     * Set the content width based on the theme's design and stylesheet.
     */
    global $content_width; 
    if ( ! isset( $content_width ) ) {
    	$content_width = 640; /* pixels */
    }

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Narcissism, use a find and replace
	 * to change 'narcissism' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'narcissism', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'narcissism' ),
	) );

	// Enable support for Post Formats.
	add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link' ) );

	// Enable support for HTML5 markup.
	add_theme_support( 'html5', array(
		'comment-list',
		'search-form',
		'comment-form',
		'gallery',
	) );
}
endif; // narcissism_setup
add_action( 'after_setup_theme', 'narcissism_setup' );

/**
 * Register widgetized area and update sidebar with default widgets.
 */
function narcissism_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Colophon', 'narcissism' ),
		'id'            => 'colophon-sidebar',
		'description'   => __( 'This sidebar appears in the header.', 'narcissism' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'narcissism_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function narcissism_scripts() {
    wp_enqueue_style( 'narcissism-google-fonts', '//fonts.googleapis.com/css?family=Nixie+One|Ledger' );
    
    wp_enqueue_style( 'narcissism-genericons', get_template_directory_uri() . '/inc/genericons/genericons.css' );
    
	wp_enqueue_style( 'narcissism-style', get_stylesheet_uri() );
    
	wp_enqueue_script( 'narcissism-navigation', get_template_directory_uri() . '/inc/js/toggles.js', array( 'jquery' ), null, true );

	wp_enqueue_script( 'narcissism-skip-link-focus-fix', get_template_directory_uri() . '/inc/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'narcissism_scripts' );

if ( ! function_exists( 'narcissism_extra_options' ) ) :
/**
 * Add theme options to the Customizer
 */
function narcissism_extra_options( $wp_customize ) {
    $wp_customize->add_section( 'na_footer_text', array(
        'title'       => __( 'Footer Text', 'narcissism' ),
        'description' => __( 'Text entered in this form will appear in the footer in place of the default text. A limited amount of HTML may be used.', 'narcissism' ),
        'priority'    => 35
    ) );
    
    $wp_customize->add_setting( 'narcissism_theme_options[footer_text]', array(
        'default'           => '',
        'type'              => 'option',
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'wp_kses'
    ) );
    
    $wp_customize->add_control( 'narcissism_theme_options[footer_text]', array(
        'label'    => __( 'Footer Text', 'narcissism' ),
        'section'  => 'na_footer_text',
        'settings' => 'narcissism_theme_options[footer_text]',
        'type'     => 'text'
    ) );
}
endif;
add_action( 'customize_register', 'narcissism_extra_options' );

if ( ! function_exists( 'narcissism_comments' ) ) :
/**
 * Callback function for layout of comments
 */
function narcissism_comments( $comment, $args, $depth ) {
    $GLOBALS['comment'] = $comment;
    global $post;

    if ( 'pingback' == $comment->comment_type || 'trackback' == $comment->comment_type ) : ?>
        <li id="div-comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
            <article class="comment-body">
                <header class="comment-meta">
                    <cite><?php _e( 'Pingback:', 'narcissism' ); ?></cite>
                    
                    <?php edit_comment_link( __( 'Edit', 'narcissism' ) ); ?>
                </header>
                
                <section class="pingback-content">
                    <?php comment_author_link(); ?>
                </section>
            </article>
        </li>
    <?php else : ?>
        <li <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?>>
            <article id="comment-<?php comment_ID(); ?>" class="comment-body">
                <header class="comment-meta">
                    <?php
                    if ( '0' != $args['avatar_size'] ) :
                        echo get_avatar( $comment, $args['avatar_size'] );
                    endif;
                    ?>
                    
                    <cite class="fn"><?php echo get_comment_author_link(); ?></cite>
                    <br />
                    <a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
                        <time datetime="<?php comment_time( 'c' ); ?>">
                            <?php printf( _x( '%1$s, %2$s', '1: date, 2: time', 'narcissism' ),
                                get_comment_date(), /* %1$s */
                                get_comment_time() /* %2$s */
                            ); ?>
                        </time>
                    </a>
                </header>
                
                <section class="comment-content">
                    <?php
                    if ( '0' == $comment->comment_approved ) : ?>
                        <p><em><?php _e( 'Your comment is awaiting moderation.', 'narcissism' ); ?></em></p>
                    <?php endif; ?>
                    
                    <p><?php comment_text(); ?></p>
                </section>
                
                <footer class="comment-actions">                    
                    <?php 
                    comment_reply_link( array_merge( $args, array(
                        'add_below' => 'comment',
                        'depth'     => $depth,
                        'max_depth' => $args['max_depth']
                    ) ) );
                    ?>
                    
                    <?php edit_comment_link( __( 'Edit', 'narcissism' ) ); ?>
                </footer>
            </article>
        </li>
    <?php endif; ?>                   
<?php }               
endif;

/**
 * Implement the Custom Header feature.
 */
//require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
